@@ -120,7 +120,7 @@ class ListWidget(QListWidget):
         text, ok = QInputDialog.getText(self, QCoreApplication.translate("DescriptionWidget", "Add Item"), QCoreApplication.translate("DescriptionWidget", "Please enter a new list item"))
         if not ok:
             return
-        item = QListWidgetItem(text)
+        item = QListWidgetItem(text.strip())
         item.setData(42, {})
         self._list_widget.addItem(item)
         self._description_widget.update_preview()
@@ -273,4 +273,4 @@ class DescriptionWidget(QWidget):
         self.get_tags(body, preview=True)
         self.description_preview.setHtml(etree.tostring(body).decode("utf-8"))
         if self._main_window:
-            self._main_window.set_file_edited()
\ No newline at end of file
+            self._main_window.set_file_edited()
